<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

//It checks if the theme supports the blog page mobile version
function eos_scfm_is_posts_page_supported( $feature ){
	$arr = get_theme_support( 'specific_content_form_mobile' );
	if( is_array( $arr ) ){
		$arr = $arr[0];
		return isset( $arr[$feature] ) && $arr[$feature];
	}
	return false;
}

add_filter( 'load_textdomain_mofile', 'eos_scfm_load_translation_file',99,2 ); //loads plugin translation files
//Filter function to read plugin translation files
function eos_scfm_load_translation_file( $mofile, $domain ) {
	if ( 'eos-scfm' === $domain ) {
		$loc = function_exists( 'get_user_locale' ) ? get_user_locale() : get_locale();
		$mofile = EOS_SCFM_PLUGIN_DIR.'/languages/eos-scfm-' . $loc . '.mo';
	}
	return $mofile;
}
load_plugin_textdomain( 'eos-scfm',false,EOS_SCFM_PLUGIN_DIR.'/languages/' );

add_action( 'admin_enqueue_scripts','eos_scfm_enqueue_scripts' );
//It enqueues the admin scripts and style
function eos_scfm_enqueue_scripts(){
	wp_enqueue_style( 'eos-scfm',EOS_SCFM_PLUGIN_URL.'/admin/assets/eos-scfm-admin.css' );
}
add_action( 'admin_action_eos_scfm_duplicate_post_as_draft', 'eos_scfm_duplicate_post_as_draft' );
//It creates post duplicate as a draft and redirects then to the edit post screen
function eos_scfm_duplicate_post_as_draft(){
	global $wpdb;
	if (! ( isset( $_GET['post'] ) || ( isset($_REQUEST['action']) && 'eos_scfm_duplicate_post_as_draft' == $_REQUEST['action'] ) ) ) {
		wp_die( __( 'No post for mobile has been supplied!','eos-scfm' ) );
	}
	$post_id = absint( $_GET['post'] );
	if( 0 === $post_id ){
		wp_die( __( 'No post for mobile has been supplied!','eos-scfm' ) );
	}
	/*
	 * and all the original post data then
	 */
	$post = get_post( $post_id );
	$current_user = wp_get_current_user();
	$new_post_author = $current_user->ID;
	/*
	 * if post data exists, create the post duplicate
	 */
	if (isset( $post ) && $post != null) {
		/*
		 * new post data array
		 */
		$args = array(
			'comment_status' => $post->comment_status,
			'ping_status'    => $post->ping_status,
			'post_author'    => $new_post_author,
			'post_content'   => $post->post_content,
			'post_excerpt'   => $post->post_excerpt,
			'post_name'      => $post->post_name.'-mobile',
			'post_parent'    => $post->post_parent,
			'post_password'  => $post->post_password,
			'post_status'    => 'draft',
			'post_title'     => $post->post_title,
			'post_type'      => $post->post_type,
			'to_ping'        => $post->to_ping,
			'menu_order'     => $post->menu_order
		);
		/*
		 * insert the post by wp_insert_post() function
		 */
		$new_post_id = wp_insert_post( $args );
		update_post_meta( $post_id,'eos_scfm_mobile_post_id',$new_post_id );
		update_post_meta( $new_post_id,'eos_scfm_desktop_post_id',$post_id );
		/*
		 * get all current post terms ad set them to the new post draft
		 */
		$taxonomies = get_object_taxonomies($post->post_type); // returns array of taxonomy names for post type, ex array("category", "post_tag");
		foreach ($taxonomies as $taxonomy) {
			$post_terms = wp_get_object_terms($post_id, $taxonomy, array('fields' => 'slugs'));
			wp_set_object_terms($new_post_id, $post_terms, $taxonomy, false);
		}
		/*
		 * duplicate all post meta just in two SQL queries
		 */
		$post_meta_infos = $wpdb->get_results("SELECT meta_key, meta_value FROM $wpdb->postmeta WHERE post_id=$post_id");
		if ( count( $post_meta_infos)!=0 ) {
			$sql_query = "INSERT INTO $wpdb->postmeta (post_id, meta_key, meta_value) ";
			foreach ($post_meta_infos as $meta_info) {
				$meta_key = $meta_info->meta_key;
				$meta_value = addslashes($meta_info->meta_value);
				$sql_query_sel[]= "SELECT $new_post_id, '$meta_key', '$meta_value'";
			}
			$sql_query.= implode(" UNION ALL ", $sql_query_sel);
			if( !in_array( $meta_key,array( 'eos_scfm_mobile_post_id','eos_scfm_desktop_post_id' ) ) ){
				$wpdb->query($sql_query);
			}
		}
		/*
		 * finally, redirect to the edit post screen for the new draft
		 */
		wp_redirect( admin_url( 'post.php?action=edit&post=' . $new_post_id ) );
		exit;
	} else {
		wp_die( sprintf( __( 'Mobile version failed, could not find original post: %s','eos-scfm' ),$post_id ) );
	}
}
add_filter( 'post_row_actions', 'eos_scfm_duplicate_post_link', 10, 2 );
add_filter( 'page_row_actions', 'eos_scfm_duplicate_post_link', 10, 2 );

//Add the duplicate link to action list for post_row_actions
function eos_scfm_duplicate_post_link( $actions,$post ) {
	if ( current_user_can('edit_posts') && in_array( $post->post_type,array( 'post','page' ) ) ){
		$mobile_post_id = absint( get_post_meta( $post->ID,'eos_scfm_mobile_post_id',true ) );
		if( $mobile_post_id  > 0 ){
			$actions['duplicate_for_mobile'] = '<a href="'.admin_url( 'post.php?action=edit&amp;post=' . $mobile_post_id ).'" title="'.esc_html__( ' Create mobile version','eos-scfm' ).'" rel="permalink">'.esc_html__( ' Edit mobile version','eos-scfm' ).'</a>';
		}
		else{
			$desktop_post_id = eos_scfm_related_desktop_id( $post->ID,true );
			if( 0 === $desktop_post_id ){
				$actions['edit_mobile'] = '<a href="admin.php?action=eos_scfm_duplicate_post_as_draft&amp;post=' . $post->ID . '" title="'.esc_html__( ' Create mobile version','eos-scfm' ).'" rel="permalink">'.esc_html__( ' Create mobile version','eos-scfm' ).'</a>';
			}
		}
	}
	return $actions;
}

add_action( 'admin_notices', 'eos_scfm_notices',10,2 );
//It adds the plugin metaboxes
function eos_scfm_notices(){
	if( !isset( $_GET['post'] ) ) return;
	global $post;
	if( !is_object( $post ) ) return;
	$desktop_post_id = absint( get_post_meta( $post->ID,'eos_scfm_desktop_post_id',true ) );
	$notice = false;
	if( $desktop_post_id > 0 ){
		$desktop_post = get_post( $desktop_post_id );
		if( is_object( $desktop_post ) ){
			$desktop_title = $desktop_post->post_title;
			$notice = sprintf( __( 'The content you are editing is the mobile version of %s%s%s','eos-scfm' ),'<strong>',$desktop_title,'</strong>' );
		}
	}
	$mobile_post_id = absint( get_post_meta( $post->ID,'eos_scfm_mobile_post_id',true ) );
	if( $mobile_post_id > 0 ){
		$mobile_post = get_post( $mobile_post_id );
		if( !is_object( $mobile_post ) ){
			$mobile_title = $mobile_post->post_title;
			$notice = sprintf( __( 'The content you are editing has a mobile version titled %s%s%s','eos-scfm' ),'<strong>',$mobile_title,'</strong>' );
		}
	}
	if( $notice ){
	?>
	<div class="notice notice-warning is-dismissible"><p><?php echo wp_kses( $notice,array( 'strong'=>array() ) ); ?></p></div>
	<?php
	}
}
add_filter( 'display_post_states','eos_scfm_post_status',2,99 );
//It adds the mobile version status in the posts table
function eos_scfm_post_status( $states, $post ){
	$desktop_post_id = eos_scfm_related_desktop_id( $post->ID,true );
	if( $desktop_post_id ){
		$desktop_post = get_post( $desktop_post_id );
		$states[] = sprintf( esc_html__( '%s Mobile Version of %s','eos-scfm' ),'<span class="dashicons dashicons-smartphone"> </span>',$desktop_post->post_title ); 
	}
	return $states;
}

add_filter( 'manage_post_posts_columns', 'eos_scfm_post_columns_head' );
add_filter( 'manage_page_posts_columns', 'eos_scfm_post_columns_head' );
//Add new column to posts table list
function eos_scfm_post_columns_head( $columns ){
	$cb = $columns['cb'];
	unset( $columns['cb'] );
	$title = $columns['title'];
	unset( $columns['title'] );
	$GLOBALS['scfm_is_blog_page_supported'] = eos_scfm_is_posts_page_supported( 'posts_page' );
	$GLOBALS['scfm_posts_page'] = get_option( 'page_for_posts' );
    return array_merge( array(
			'cb' => $cb,
			'title' => $title,
			'eos_scfm_device' => '<span class="dashicons dashicons-desktop"></span>|<span class="dashicons dashicons-smartphone"></span>',
		),$columns
	);
}
add_action( 'manage_posts_custom_column', 'eos_scfm_post_columns_content', 10, 2 );
add_action( 'manage_pages_custom_column', 'eos_scfm_post_columns_content', 10, 2 );
//Set the content for the added column in the posts table lists
function eos_scfm_post_columns_content( $column_name, $post_ID ) {
    if( $column_name === 'eos_scfm_device' ) {
		$desktop_id = eos_scfm_related_desktop_id( $post_ID );
		$mobile_id = eos_scfm_related_mobile_id( $post_ID );
		$desktop_id_link = $desktop_id > 0 ? $desktop_id : $post_ID;
		$mobile_id_link = $mobile_id > 0 ? $mobile_id : '';
		$desktop_link = '' !== $desktop_id_link ? array( '<a title="'.esc_attr__( 'Edit Desktop version','eos-scfm' ).'" href="'.get_edit_post_link( $desktop_id_link ).'">','</a>' ) : array( '','' );
		$mobile_link = $mobile_id > 0 || $desktop_id > 0 ? array( '<a title="'.esc_attr__( 'Edit Mobile version','eos-scfm' ).'" href="'.get_edit_post_link( $mobile_id_link ).'">','</a>' ) : array( '','' );
		$mobile_display = $desktop_id > 0 || $mobile_id > 0 ? 'inline-block' : 'none';
		$desktop_opacity  = $desktop_id_link > 0 || $mobile_id > 0 ? 1 : 0.4;
		$mobile_new = 'none' === $mobile_display ? '<a href="admin.php?action=eos_scfm_duplicate_post_as_draft&amp;post='.absint( $post_ID ).'" title="'.esc_html__( ' Create mobile version','eos-scfm' ).'" rel="permalink"><span class="dashicons dashicons-plus"></span></a>' : '';
		echo $desktop_link[0].'<span style="opacity:'.esc_attr( $desktop_opacity ).'" class="dashicons dashicons-desktop"></span>'.$desktop_link[1].$mobile_link[0].'<span style="display:'.$mobile_display.'" class="dashicons dashicons-smartphone"></span>'.$mobile_link[1].$mobile_new;
		global $scfm_is_blog_page_supported,$scfm_posts_page;
		if( !$scfm_is_blog_page_supported && $post_ID === absint( $scfm_posts_page ) ){
			?>
			<span class="dashicons dashicons-info" title="<?php esc_attr_e( "Your theme doesn't declare full support for the blog page mobile version, something may not work as expected on the blog mobile version","eos-scfm" ); ?>"></span>
			<?php
			return;
		}		
    }
}
add_action( 'wp_trash_post','eos_scfm_before_post_deletion' );
//it manages the mobile and desktop versions when a post or page is deleted
function eos_scfm_before_post_deletion( $post_id ){
	global $post_type;
	if( !in_array( $post_type,array( 'post','page'  ) ) ) return;
	$desktop_id = eos_scfm_related_desktop_id( $post_id );
	$mobile_id = eos_scfm_related_mobile_id( $post_id );
	if( $desktop_id > 0 ){
		delete_post_meta( $desktop_id,'eos_scfm_desktop_post_id' );
	}
	if( $mobile_id > 0 ){
		wp_trash_post( $mobile_id );
	}
}

add_filter( 'plugin_action_links_'.EOS_SCFM_PLUGIN_BASE_NAME,'eos_scfm_plugin_add_settings_link' );
//It adds a link to the action links in the plugins page
function eos_scfm_plugin_add_settings_link( $links ){
    $settings_link = '<a class="eos-wh-setts" href="'.admin_url( 'edit.php?post_type=page' ).'">'. __( 'Pages Settings','eos-scfm' ). '</a>';
    $settings_link .= ' | <a class="eos-wh-setts" href="'.admin_url( 'edit.php?post_type=post' ).'">'. __( 'Posts Settings','eos-scfm' ). '</a>';
    array_push( $links, $settings_link );
  	return $links;	
}