<?php
/*
Plugin Name: Specific Content for Mobile
Description: It allows you to customize the content for mobile devices.
Author: Jose Mortellaro
Author URI: https://josemortellaro.com/
Text Domain: eos-scfm
Domain Path: /languages/
Version: 0.0.2
*/
/*  This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
*/
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if( is_admin() ){
	define( 'EOS_SCFM_PLUGIN_URL', untrailingslashit( plugins_url( '', __FILE__ ) ) );
	define( 'EOS_SCFM_PLUGIN_DIR',untrailingslashit( dirname( __FILE__ ) ) );
	define( 'EOS_SCFM_PLUGIN_BASE_NAME',untrailingslashit( plugin_basename( __FILE__ ) ) );
	require EOS_SCFM_PLUGIN_DIR.'/admin/scfm-admin.php';
}
else{
	add_action( 'parse_query','eos_scfm_post_replacement' );
}

//It replace the desktop post with the mobile post version if any
function eos_scfm_post_replacement( $query ){
	if( !$query->is_main_query() ) return;
	$query_vars = $query->query_vars;
	if( isset( $query_vars['page_id'] ) && absint( $query_vars['page_id'] ) > 0 ){
		$post_id = $query_vars['page_id'];
	}
	else{
		$queriedObj = $query->queried_object;
		if( is_object( $queriedObj ) ){
			$post_id = $queriedObj->ID;
		}
		else{
			return;
		}
	}
	if( wp_is_mobile() ){
		$mobile_post_id = eos_scfm_related_mobile_id( $post_id );
		if( 'publish' === get_post_status( $mobile_post_id ) ){
			if( $mobile_post_id > 0 ){
				if( isset( $query->is_posts_page ) && $query->is_posts_page ){
					$new_blog_page = get_post( $mobile_post_id );
					$queriedObj->ID = $mobile_post_id;
					$queriedObj->queried_object_id = $mobile_post_id;
					$queriedObj->post_content = $new_blog_page->post_content;
					$query->queried_object_id = $mobile_post_id;
					$query->set( 'queried_object',$queriedObj );
				}
				else{
					$query->set( 'page_id',$mobile_post_id );
				}
			}
			return true;
		}
	}
	remove_action( 'wp_head','rel_canonical' );
	add_action( 'wp_head','eos_scfm_head_actions',10 );
	return false;
}

//It adds the canonical URL link in case of mobile content shown on desktop
function eos_scfm_head_actions(){
	global $post;
	if( !is_object( $post ) ) return;
	$desktop_post_id = eos_scfm_related_desktop_id( $post->ID );
	if( $desktop_post_id > 0 ){
		?>
		<link rel="canonical" href="<?php the_permalink( $desktop_post_id ); ?>" />
		<?php
	}	
}

//It returns the post ID related to the desktop version given the original post ID
function eos_scfm_related_desktop_id( $post_id ){
	return absint( get_post_meta( $post_id,'eos_scfm_desktop_post_id',true ) );
}

//It returns the post ID related to the mobile version given the original post ID
function eos_scfm_related_mobile_id( $post_id ){
	return absint( get_post_meta( $post_id,'eos_scfm_mobile_post_id',true ) );
}

if( class_exists( 'WooCommerce' ) ){
	//Integration with WooCommerce
	add_filter( 'woocommerce_get_shop_page_id','eos_scfm_woo_shop_id_filter' );
	//It replaces the shop ID with the ID related to the mobile version if any
	function eos_scfm_woo_shop_id_filter( $id ){
		if( wp_is_mobile() ){
			$mobile_post_id = absint( get_post_meta( $id,'eos_scfm_mobile_post_id',true ) );
			if( $mobile_post_id > 0 ){
				return $mobile_post_id;
			}
		}
		return $id;
	}
}